@@ -11,14 +11,6 @@ typedef Eo Efl_Ui_Widget;
 #ifndef _EFL_UI_WIDGET_EO_TYPES
 #define _EFL_UI_WIDGET_EO_TYPES
 
-#ifdef EFL_BETA_API_SUPPORT
-/** Function pointer for on show region hook
- *
- * @ingroup Efl_Ui
- */
-typedef void (*Efl_Ui_Scrollable_On_Show_Region)(void *data, Efl_Canvas_Object *obj, Eina_Rect region);
-#endif /* EFL_BETA_API_SUPPORT */
-
 /** All relevant fields needed for the current state of focus registration
  *
  * @since 1.22
@@ -36,7 +28,19 @@ typedef struct _Efl_Ui_Widget_Focus_State
 
 
 #endif
-/** Efl UI widget abstract class
+/**
+ * @brief Base class for all Efl.Ui.* widgets
+ *
+ * The class here is designed in a way that widgets can be expressed as a tree.
+ * The parent relation in the tree can be fetched via
+ * @ref efl_ui_widget_parent_get . The parent relation should never be modified
+ * directly, instead you should use the APIs of the widgets (Typically
+ * @ref Efl_Pack_Linear, @ref Efl_Pack_Table or @ref Efl_Content).
+ *
+ * Properties implemented here should be treated with extra care, some are
+ * defined for the sub-tree, others are defined for the widget itself,
+ * additional information for this can be fetched from the documentation in the
+ * implements section.
  *
  * @since 1.22
  *
@@ -115,7 +119,7 @@ EOAPI const char *efl_ui_widget_cursor_get(const Eo *obj);
  * @ref efl_ui_widget_cursor_set.
  *
  * @param[in] obj The object.
- * @param[in] style A specific style to use, eg. default, transparent, ....
+ * @param[in] style A specific style to use, e.g. default, transparent, ....
  *
  * @return @c true if successful.
  *
@@ -138,7 +142,7 @@ EOAPI Eina_Bool efl_ui_widget_cursor_style_set(Eo *obj, const char *style);
  *
  * @param[in] obj The object.
  *
- * @return A specific style to use, eg. default, transparent, ....
+ * @return A specific style to use, e.g. default, transparent, ....
  *
  * @since 1.22
  *
@@ -211,10 +215,6 @@ EOAPI void efl_ui_widget_resize_object_set(Eo *obj, Efl_Canvas_Object *sobj);
 /**
  * @brief Whether the widget is enabled (accepts and reacts to user inputs).
  *
- * The property works counted, this means, whenever n-caller set the value to
- * @c true, n-caller have to set it to @c false in order to get it out of the
- * disabled state again.
- *
  * Each widget may handle the disabled state differently, but overall disabled
  * widgets shall not respond to any input events. This is @c false by default,
  * meaning the widget is enabled.
@@ -236,10 +236,6 @@ EOAPI void efl_ui_widget_disabled_set(Eo *obj, Eina_Bool disabled);
 /**
  * @brief Whether the widget is enabled (accepts and reacts to user inputs).
  *
- * The property works counted, this means, whenever n-caller set the value to
- * @c true, n-caller have to set it to @c false in order to get it out of the
- * disabled state again.
- *
  * Each widget may handle the disabled state differently, but overall disabled
  * widgets shall not respond to any input events. This is @c false by default,
  * meaning the widget is enabled.
@@ -260,7 +256,6 @@ EOAPI void efl_ui_widget_disabled_set(Eo *obj, Eina_Bool disabled);
  */
 EOAPI Eina_Bool efl_ui_widget_disabled_get(const Eo *obj);
 
-#ifdef EFL_UI_WIDGET_PROTECTED
 /**
  * @brief The widget style to use.
  *
@@ -285,7 +280,6 @@ EOAPI Eina_Bool efl_ui_widget_disabled_get(const Eo *obj);
  * @ingroup Efl_Ui_Widget
  */
 EOAPI Eina_Error efl_ui_widget_style_set(Eo *obj, const char *style);
-#endif
 
 /**
  * @brief The widget style to use.
@@ -347,7 +341,7 @@ EOAPI Eina_Bool efl_ui_widget_input_event_handler(Eo *obj, const Efl_Event *eo_e
  * @note Objects which are meant to be interacted with by input events are
  * created able to be focused, by default. All the others are not.
  *
- * This property's default value depends on the widget (eg. a box is not
+ * This property's default value depends on the widget (e.g. a box is not
  * focusable, but a button is).
  *
  * @param[in] obj The object.
@@ -370,7 +364,7 @@ EOAPI void efl_ui_widget_focus_allow_set(Eo *obj, Eina_Bool can_focus);
  * @note Objects which are meant to be interacted with by input events are
  * created able to be focused, by default. All the others are not.
  *
- * This property's default value depends on the widget (eg. a box is not
+ * This property's default value depends on the widget (e.g. a box is not
  * focusable, but a button is).
  *
  * @param[in] obj The object.
