@@ -20,11 +20,11 @@ typedef Eo Elm_Interface_Scrollable;
  */
 typedef enum
 {
-  ELM_SCROLLER_POLICY_AUTO = 0, /**< Show scrollbars as needed */
-  ELM_SCROLLER_POLICY_ON, /**< Always show scrollbars */
-  ELM_SCROLLER_POLICY_OFF, /**< Never show scrollbars */
-  ELM_SCROLLER_POLICY_LAST /**< Sentinel value to indicate last enum field
-                            * during iteration */
+  ELM_SCROLLER_POLICY_AUTO = 0, /**< Show scrollbars as needed. */
+  ELM_SCROLLER_POLICY_ON, /**< Always show scrollbars. */
+  ELM_SCROLLER_POLICY_OFF, /**< Never show scrollbars. */
+  ELM_SCROLLER_POLICY_LAST /**< Internal. Sentinel value to indicate last enum
+                            * field during iteration. */
 } Elm_Scroller_Policy;
 
 /**
@@ -36,12 +36,12 @@ typedef enum
  */
 typedef enum
 {
-  ELM_SCROLLER_SINGLE_DIRECTION_NONE = 0, /**< Scroll every direction */
+  ELM_SCROLLER_SINGLE_DIRECTION_NONE = 0, /**< Scroll every direction. */
   ELM_SCROLLER_SINGLE_DIRECTION_SOFT, /**< Scroll single direction if the
-                                       * direction is certain */
-  ELM_SCROLLER_SINGLE_DIRECTION_HARD, /**< Scroll only single direction */
-  ELM_SCROLLER_SINGLE_DIRECTION_LAST /**< Sentinel value to indicate last enum
-                                      * field during iteration */
+                                       * direction is certain. */
+  ELM_SCROLLER_SINGLE_DIRECTION_HARD, /**< Scroll only single direction. */
+  ELM_SCROLLER_SINGLE_DIRECTION_LAST /**< Internal. Sentinel value to indicate
+                                      * last enum field during iteration. */
 } Elm_Scroller_Single_Direction;
 
 
@@ -173,7 +173,7 @@ EOAPI Eina_Bool elm_interface_scrollable_wheel_disabled_get(const Eo *obj);
  *
  * @ingroup Elm_Interface_Scrollable
  */
-EOAPI void elm_interface_scrollable_movement_block_set(Eo *obj, Efl_Ui_Scroll_Block block);
+EOAPI void elm_interface_scrollable_movement_block_set(Eo *obj, Efl_Ui_Layout_Orientation block);
 
 /**
  * @brief Blocking of scrolling (per axis)
@@ -193,7 +193,7 @@ EOAPI void elm_interface_scrollable_movement_block_set(Eo *obj, Efl_Ui_Scroll_Bl
  *
  * @ingroup Elm_Interface_Scrollable
  */
-EOAPI Efl_Ui_Scroll_Block elm_interface_scrollable_movement_block_get(const Eo *obj);
+EOAPI Efl_Ui_Layout_Orientation elm_interface_scrollable_movement_block_get(const Eo *obj);
 
 /**
  * @brief Momentum animator
@@ -219,11 +219,6 @@ EOAPI Eina_Bool elm_interface_scrollable_momentum_animator_disabled_get(const Eo
 /**
  * @brief Scrollbar visibility policy
  *
- * #ELM_SCROLLER_POLICY_AUTO means the scrollbar is made visible if it is
- * needed, and otherwise kept hidden. #ELM_SCROLLER_POLICY_ON turns it on all
- * the time, and #ELM_SCROLLER_POLICY_OFF always keeps it off. This applies
- * respectively for the horizontal and vertical scrollbars.
- *
  * @param[in] obj The object.
  * @param[in] hbar Horizontal scrollbar policy
  * @param[in] vbar Vertical scrollbar policy
@@ -235,11 +230,6 @@ EOAPI void elm_interface_scrollable_policy_set(Eo *obj, Elm_Scroller_Policy hbar
 /**
  * @brief Scrollbar visibility policy
  *
- * #ELM_SCROLLER_POLICY_AUTO means the scrollbar is made visible if it is
- * needed, and otherwise kept hidden. #ELM_SCROLLER_POLICY_ON turns it on all
- * the time, and #ELM_SCROLLER_POLICY_OFF always keeps it off. This applies
- * respectively for the horizontal and vertical scrollbars.
- *
  * @param[in] obj The object.
  * @param[out] hbar Horizontal scrollbar policy
  * @param[out] vbar Vertical scrollbar policy
@@ -443,7 +433,7 @@ EOAPI void elm_interface_scrollable_page_snap_allow_set(Eo *obj, Eina_Bool horiz
 EOAPI void elm_interface_scrollable_page_snap_allow_get(const Eo *obj, Eina_Bool *horiz, Eina_Bool *vert);
 
 /**
- * @brief Pagin property
+ * @brief Paging property
  *
  * @param[in] obj The object.
  * @param[in] pagerel_h Page relation horizontal
@@ -456,7 +446,7 @@ EOAPI void elm_interface_scrollable_page_snap_allow_get(const Eo *obj, Eina_Bool
 EOAPI void elm_interface_scrollable_paging_set(Eo *obj, double pagerel_h, double pagerel_v, int pagesize_h, int pagesize_v);
 
 /**
- * @brief Pagin property
+ * @brief Paging property
  *
  * @param[in] obj The object.
  * @param[out] pagerel_h Page relation horizontal
@@ -838,7 +828,7 @@ EOAPI void elm_interface_scrollable_edge_top_cb_set(Eo *obj, Elm_Interface_Scrol
 EOAPI void elm_interface_scrollable_objects_set(Eo *obj, Efl_Canvas_Object *edje_object, Efl_Canvas_Object *hit_rectangle);
 
 /**
- * @brief Get scroll last page number.
+ * @brief Scroll last page number.
  *
  * The page number starts from 0. 0 is the first page. This returns the last
  * page number among the pages.
@@ -856,7 +846,7 @@ EOAPI void elm_interface_scrollable_objects_set(Eo *obj, Efl_Canvas_Object *edje
 EOAPI void elm_interface_scrollable_last_page_get(const Eo *obj, int *pagenumber_h, int *pagenumber_v);
 
 /**
- * @brief Get scroll current page number.
+ * @brief Scroll current page number.
  *
  * The page number starts from 0. 0 is the first page. Current page means the
  * page which meets the top-left of the viewport. If there are two or more
